##########
As Package
##########

*****************************************
Conda
*****************************************

ADIOS2 can be obtained from anaconda cloud:  `conda-forge adios2 <https://anaconda.org/conda-forge/adios2>`_

*****************************************
PyPI
*****************************************

ADIOS2 pip package can be downloaded with `pip3 install adios2` or `python3 -m pip install adios2`. This is contains the serial build only, so MPI programs cannot use it. See `adios2 on PyPi <https://pypi.org/project/adios2/>`_

*****************************************
Spack
*****************************************

ADIOS2 is packaged in Spack. See `adios2 spack package <https://packages.spack.io/package.html?name=adios2>`_

*****************************************
Docker
*****************************************

Docker images including building and installation of dependencies and ADIOS 2 containers for Ubuntu 20 and CentOS 7 can be found in: 
under the directory `scripts/docker/ <https://github.com/ornladios/ADIOS2/tree/master/scripts/docker>`_
